summaryrefslogtreecommitdiffstats
path: root/kfilereplace
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:51:30 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-24 13:51:30 -0600
commit29df04c24350cc76a41e2410d1c92445f9338b98 (patch)
treec2b9cde128e24275393a83d9eaec58b2ef12d109 /kfilereplace
parentc70534eef6085384ef7ddff369a154dbc8901917 (diff)
downloadtdewebdev-29df04c24350cc76a41e2410d1c92445f9338b98.tar.gz
tdewebdev-29df04c24350cc76a41e2410d1c92445f9338b98.zip
Rename KGlobal, KProcess, and KClipboard to avoid conflicts with KDE4
Diffstat (limited to 'kfilereplace')
-rw-r--r--kfilereplace/commandengine.cpp18
-rw-r--r--kfilereplace/commandengine.h8
-rw-r--r--kfilereplace/kfilereplace.cpp4
-rw-r--r--kfilereplace/kfilereplacepart.cpp2
-rw-r--r--kfilereplace/knewprojectdlg.cpp2
-rw-r--r--kfilereplace/koptionsdlg.cpp2
6 files changed, 18 insertions, 18 deletions
diff --git a/kfilereplace/commandengine.h b/kfilereplace/commandengine.h
index 702edeee..36bcfcb8 100644
--- a/kfilereplace/commandengine.h
+++ b/kfilereplace/commandengine.h
@@ -24,7 +24,7 @@ class TQString;
#include <tqobject.h>
//KDE
-class KProcess;
+class TDEProcess;
class CommandEngine : public TQObject
{
@@ -50,9 +50,9 @@ class CommandEngine : public TQObject
TQString variableValue(const TQString &variable);
private slots:
- void slotGetScriptOutput(KProcess*,char*,int);
- void slotGetScriptError(KProcess*,char*,int);
- void slotProcessExited(KProcess*);
+ void slotGetScriptOutput(TDEProcess*,char*,int);
+ void slotGetScriptError(TDEProcess*,char*,int);
+ void slotProcessExited(TDEProcess*);
};
#endif // COMMANDENGINE_H
diff --git a/kfilereplace/kfilereplace.cpp b/kfilereplace/kfilereplace.cpp
index 35428a7b..a0976658 100644
--- a/kfilereplace/kfilereplace.cpp
+++ b/kfilereplace/kfilereplace.cpp
@@ -76,7 +76,7 @@ void KFileReplace::slotConfigureKeys()
void KFileReplace::slotConfigureToolbars()
{
- saveMainWindowSettings(KGlobal::config(), autoSaveGroup());
+ saveMainWindowSettings(TDEGlobal::config(), autoSaveGroup());
KEditToolbar dlg(factory());
connect(&dlg, TQT_SIGNAL(newToolbarConfig()),
this, TQT_SLOT(applyNewToolbarConfig()));
@@ -85,7 +85,7 @@ void KFileReplace::slotConfigureToolbars()
void KFileReplace::applyNewToolbarConfig()
{
- applyMainWindowSettings(KGlobal::config(), autoSaveGroup());
+ applyMainWindowSettings(TDEGlobal::config(), autoSaveGroup());
}
diff --git a/kfilereplace/kfilereplacepart.cpp b/kfilereplace/kfilereplacepart.cpp
index d52f0061..8d24a84c 100644
--- a/kfilereplace/kfilereplacepart.cpp
+++ b/kfilereplace/kfilereplacepart.cpp
@@ -63,7 +63,7 @@ K_EXPORT_COMPONENT_FACTORY( libkfilereplacepart, FileReplaceFactory )
KFileReplacePart::KFileReplacePart(TQWidget* parentWidget, const char* , TQObject* parent, const char* name, const TQStringList & ) : KParts::ReadOnlyPart(parent,name)
{
setInstance(FileReplaceFactory::instance());
- KGlobal::locale()->insertCatalogue("kfilereplace");
+ TDEGlobal::locale()->insertCatalogue("kfilereplace");
m_parentWidget = parentWidget;
m_config = new KConfig("kfilereplacerc");
m_aboutDlg = 0;
diff --git a/kfilereplace/knewprojectdlg.cpp b/kfilereplace/knewprojectdlg.cpp
index 21e986ad..b610990e 100644
--- a/kfilereplace/knewprojectdlg.cpp
+++ b/kfilereplace/knewprojectdlg.cpp
@@ -224,7 +224,7 @@ void KNewProjectDlg::initGUI()
void KNewProjectDlg::loadOptions()
{
- TQStringList availableEncodingNames(KGlobal::charsets()->availableEncodingNames());
+ TQStringList availableEncodingNames(TDEGlobal::charsets()->availableEncodingNames());
m_cbEncoding->insertStringList(availableEncodingNames);
int idx = -1;
int utf8Idx = -1;
diff --git a/kfilereplace/koptionsdlg.cpp b/kfilereplace/koptionsdlg.cpp
index 35f0a3da..20d80e47 100644
--- a/kfilereplace/koptionsdlg.cpp
+++ b/kfilereplace/koptionsdlg.cpp
@@ -153,7 +153,7 @@ void KOptionsDlg::initGUI()
m_chbShowConfirmDialog->setChecked(true);
}
- TQStringList availableEncodingNames(KGlobal::charsets()->availableEncodingNames());
+ TQStringList availableEncodingNames(TDEGlobal::charsets()->availableEncodingNames());
m_cbEncoding->insertStringList( availableEncodingNames );
int idx = -1;
int utf8Idx = -1;
diff --git a/kfilereplace/commandengine.cpp b/kfilereplace/commandengine.cpp
index af3cd2f2..5184773c 100644
--- a/kfilereplace/commandengine.cpp
+++ b/kfilereplace/commandengine.cpp
@@ -98,18 +98,18 @@ TQString CommandEngine::mathexp(const TQString& opt, const TQString& arg)
TQString program = "var=("+tempOpt+");print var";
TQString script = "echo '"+program+"' | bc -l;";
- KProcess* proc = new KProcess();
+ TDEProcess* proc = new TDEProcess();
proc->setUseShell(true);
*(proc) << script;
- connect(proc, TQT_SIGNAL(receivedStdout(KProcess*,char*,int)), this, TQT_SLOT(slotGetScriptOutput(KProcess*,char*,int)));
- connect(proc, TQT_SIGNAL(receivedStderr(KProcess*,char*,int)), this, TQT_SLOT(slotGetScriptError(KProcess*,char*,int)));
- connect(proc, TQT_SIGNAL(processExited(KProcess*)), this, TQT_SLOT(slotProcessExited(KProcess*)));
+ connect(proc, TQT_SIGNAL(receivedStdout(TDEProcess*,char*,int)), this, TQT_SLOT(slotGetScriptOutput(TDEProcess*,char*,int)));
+ connect(proc, TQT_SIGNAL(receivedStderr(TDEProcess*,char*,int)), this, TQT_SLOT(slotGetScriptError(TDEProcess*,char*,int)));
+ connect(proc, TQT_SIGNAL(processExited(TDEProcess*)), this, TQT_SLOT(slotProcessExited(TDEProcess*)));
- //Through slotGetScriptOutput, m_processOutput contains the result of the KProcess call
- if(!proc->start(KProcess::Block, KProcess::All))
+ //Through slotGetScriptOutput, m_processOutput contains the result of the TDEProcess call
+ if(!proc->start(TDEProcess::Block, TDEProcess::All))
{
return TQString();
}
@@ -187,7 +187,7 @@ TQString CommandEngine::variableValue(const TQString &variable)
}
//SLOTS
-void CommandEngine::slotGetScriptError(KProcess* proc, char* s, int i)
+void CommandEngine::slotGetScriptError(TDEProcess* proc, char* s, int i)
{
Q_UNUSED(proc);
Q_UNUSED(proc);
@@ -195,7 +195,7 @@ void CommandEngine::slotGetScriptError(KProcess* proc, char* s, int i)
if(temp.isEmpty() || temp == "\n") return;
}
-void CommandEngine::slotGetScriptOutput(KProcess* proc, char* s, int i)
+void CommandEngine::slotGetScriptOutput(TDEProcess* proc, char* s, int i)
{
Q_UNUSED(proc);
TQCString temp(s,i+1);
@@ -205,7 +205,7 @@ void CommandEngine::slotGetScriptOutput(KProcess* proc, char* s, int i)
m_processOutput += TQString::fromLocal8Bit(temp);
}
-void CommandEngine::slotProcessExited(KProcess* proc)
+void CommandEngine::slotProcessExited(TDEProcess* proc)
{
Q_UNUSED(proc);
}